@@ -72,6 +72,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UCONTEXT_H 1
 #define HAVE_UTIME_H 1
+#define HAVE_SYS_EVENT_H 1
 #define HAVE_X86INTRIN_H 1
 #if defined(__x86_64__)
 #define HAVE_X86INTRIN_H 1
@@ -92,7 +93,8 @@
 #define SIZEOF_DOUBLE 8
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
-#define PACKED_STRUCT(x) x __attribute__((packed))
+#define RBIMPL_ATTR_PACKED_STRUCT_BEGIN()
+#define RBIMPL_ATTR_PACKED_STRUCT_END() __attribute__((packed))
 #define PRI_LL_PREFIX "ll"
 #define HAVE_PID_T 1
 #define rb_pid_t pid_t
@@ -273,6 +275,7 @@
 #define HAVE_EXECV 1
 #define HAVE_EXECVE 1
 #define HAVE_FCOPYFILE 1
+#define HAVE_FCHDIR 1
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
@@ -363,6 +366,7 @@
 #define HAVE_SIGALTSTACK 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SINH 1
+#define HAVE_SNPRINTF 1
 #define HAVE_SYMLINK 1
 #define HAVE_SYSCALL 1
 #define HAVE_SYSCONF 1
@@ -381,9 +385,6 @@
 #define HAVE_WAITPID 1
 #define HAVE___COSPI 1
 #define HAVE___SINPI 1
-#if !defined __STDC_WANT_LIB_EXT1__
-#define __STDC_WANT_LIB_EXT1__ 1
-#endif /* !defined __STDC_WANT_LIB_EXT1__ */
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
@@ -423,6 +424,7 @@
 #define HAVE_PTHREAD_SETNAME_NP 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(name)
+#define RB_THREAD_LOCAL_SPECIFIER _Thread_local
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
 #define HAVE_SYS_USER_H 1
 #define HAVE_CONST_PAGE_SIZE 1
@@ -446,7 +448,7 @@
 #define RUBY_SETJMP(env) sigsetjmp((env),0)
 #define RUBY_LONGJMP(env,val) siglongjmp((env),val)
 #define RUBY_JMP_BUF sigjmp_buf
-#define USE_MJIT 1
 #define USE_YJIT 0
+#define USE_RJIT 0
 #define RUBY_PLATFORM "x86_64-darwin13"
 #endif /* INCLUDE_RUBY_CONFIG_H */
