@@ -9,43 +9,43 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.2.") or
-    raise "ruby lib version (3.2.10) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.3.") or
+    raise "ruby lib version (3.3.9) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.2/3.2.0/x86_64-darwin13")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.3/3.3.0/x86_64-darwin13")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "2"
-  CONFIG["TEENY"] = "10"
-  CONFIG["PATCHLEVEL"] = "266"
+  CONFIG["MINOR"] = "3"
+  CONFIG["TEENY"] = "9"
+  CONFIG["PATCHLEVEL"] = "170"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.2"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.2"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.3"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.3"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.2.pc"
+  CONFIG["ruby_pc"] = "ruby-3.3.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
-  CONFIG["MKMF_VERBOSE"] = "0"
+  CONFIG["MKMF_VERBOSE"] = "1"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.2.10"
+  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.3.9"
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--without-gmp' '--without-jemalloc' '--with-opt-dir=/opt/local' '--program-suffix=3.2' '--with-rubyhdrdir=/opt/local/include/ruby-3.2.10' '--with-rubylibprefix=/opt/local/lib/ruby3.2' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' '--with-arch=x86_64' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64' 'CPPFLAGS=-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--disable-rjit' '--without-gmp' '--enable-mkmf-verbose' '--with-opt-dir=/opt/local' '--program-suffix=3.3' '--with-rubyhdrdir=/opt/local/include/ruby-3.3.9' '--with-rubylibprefix=/opt/local/lib/ruby3.3' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64' 'CPPFLAGS=-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.2.0"
+  CONFIG["ruby_version"] = "3.3.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin13"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -71,6 +71,7 @@ module RbConfig
   CONFIG["rubysitearchprefix"] = "$(rubylibprefix)/$(sitearch)"
   CONFIG["rubyarchprefix"] = "$(rubylibprefix)/$(arch)"
   CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
+  CONFIG["USE_LLVM_WINDRES"] = ""
   CONFIG["PLATFORM_DIR"] = ""
   CONFIG["COROUTINE_TYPE"] = "amd64"
   CONFIG["THREAD_MODEL"] = "pthread"
@@ -94,7 +95,7 @@ module RbConfig
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
-  CONFIG["EXTDLDFLAGS"] = "$(LIBRUBYARG_SHARED)"
+  CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wextra-tokens -Wdeprecated-declarations -Wdivision-by-zero -Wdiv-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wundef"
@@ -103,14 +104,14 @@ module RbConfig
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
-  CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
+  CONFIG["RJIT_SUPPORT"] = "no"
   CONFIG["YJIT_OBJ"] = ""
   CONFIG["YJIT_LIBS"] = ""
   CONFIG["CARGO_BUILD_ARGS"] = ""
   CONFIG["YJIT_SUPPORT"] = "no"
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "no"
-  CONFIG["MJIT_SUPPORT"] = "yes"
+  CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -118,7 +119,7 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.2"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.3"
   CONFIG["setup"] = "Setup"
   CONFIG["SOEXT"] = "dylib"
   CONFIG["TRY_LINK"] = ""
@@ -145,7 +146,7 @@ module RbConfig
   CONFIG["dsymutil"] = "dsymutil"
   CONFIG["codesign"] = "codesign"
   CONFIG["cleanlibs"] = "$(TARGET_SO).dSYM"
-  CONFIG["POSTLINK"] = "dsymutil $@; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
+  CONFIG["POSTLINK"] = "dsymutil $@ 2>/dev/null; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
   CONFIG["incflags"] = "-I/opt/local/include"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["RUBY_DEVEL"] = ""
@@ -171,7 +172,6 @@ module RbConfig
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION_MESSAGE"] = "Apple LLVM version 6.0 (clang-600.0.57) (based on LLVM 3.5svn)\nTarget: x86_64-apple-darwin13.4.0\nThread model: posix"
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "/usr/bin/clang -std=gnu11 -std=gnu11"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
@@ -247,7 +247,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&3.2&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&3.3&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
